# packdown

`packdown` is a convenience utility for creating dynamic `package.json` files.

## Motivation

While working on a project which made heavy use of `npm`'s `scripts` feature, I saw there were a lot of references to filepaths. There was an existing object in the system which contained references to these paths so that if they changed, files that referred to them wouldn't break. I wanted to use that object to DRY up the filepaths, but I couldn't.

Also, as the file got larger, I found myself wanting to organize it, which I also couldn't do easily since I couldn't use newlines in valid JSON.

This library is for you if, while writing your `package.json` ...

1. You want to write your `package.json` using CoffeeScript.
2. You want to put newlines and comments wherever you darn well please.
3. You want to be able to utilize external libraries.

So you can turn this:

    {
      "name": "anteater",
      "description": "Given a collection of ants, anteater will eat most of them.",
      "scripts": {
        "build": "minify ./ui/all.js",
        "eat-ants": "node ./anteater/actions/eat-ants.js"
      },
      "dependencies": {
        "express": "*",
        "q": "*"
      }
    }

Into this:

    PathTo = require './Pathfinder'

    module.exports =
      name        : 'anteater'
      description : 'Given a collection of ants, anteater will eat most of them.'

      scripts:
        "build"    : "minify #{ PathTo.file.scriptManifest }"
        "eat-ants" : "node #{ PathTo.service.EatAnts }"

      dependencies:
        # Server
        "express": "*"

        # Utility
        "q": "*"

## Usage

### Create Your Package

`packdown` expects a `Package.coffee` file to be present in the directory in which it is run. It expects this file to export a JavaScript object, like so:

    module.exports =
      name        : "anteater"
      description : "Given a collection of ants, anteater will eat most of them."

### Package It Up

From the command line, run `packdown`. Your `package.json` will be generated in the current directory.
